#!/usr/local/bin/python

import os 
import run_generator as rg
import unittest

class TestGenerator(unittest.TestCase):

	def setUp(self):
		self.url = 'http://127.0.0.1:8081'
		self.username = 'admin'
		self.password = 'password'
		self.level = 'low'
		self.n = 100
		self.m = 2
		self.username = 'admin'

	def generate_cookies(self, token, level):
		return {
			    "Cookie": "security=" + level + "; PHPSESSID=" + token
			}

	def generic_test(self, url, f, name, level, text_match, args):
		token, c = rg.login(self.url, self.username, self.password)
		cookies = self.generate_cookies(token, level)
		text, status_code, c = f(url, c, cookies, args)
		c.close()
		self.assertEqual(200, status_code)
		for t in text_match:
			if not(t in text):
				print(text)
			self.assertTrue(t in text)

	
	def run_get_level(self, level, path, text_match):
		token, c = rg.login(self.url, self.username, self.password)
		cookies = self.generate_cookies(token, level)
		text, status_code, c = rg.run_get(self.url, c, cookies, [path])
		c.close()
		self.assertEqual(200, status_code)
		self.assertTrue(text_match in text)


	def test_login(self):
		token, c = rg.login(self.url, self.username, self.password)
		c.close()

		self.assertTrue(token!='')


	def test_run_get(self):
		for level in ['low','medium','high','impossible']:
			self.run_get_level(level,'/instructions.php', 'Instructions :: Damn Vulnerable Web Application')
			self.run_get_level(level,'/setup.php', 'Setup :: Damn Vulnerable Web Application ')


	def test_run_exec(self):
		self.generic_test(self.url,
			rg.run_exec,
				'test_run_exec', 
				'low', 
				['Vulnerability: Command Injection :: Damn Vulnerable Web Application', 'PING localhost'],
				['localhost'])


	def test_run_brute(self):
		self.generic_test(self.url,
			rg.run_brute,
				'test_run_brute', 
				'low', 
				['Vulnerability: Brute Force :: Damn Vulnerable Web Application'],
				[self.username, self.password])


	def test_run_change_password(self):
		self.generic_test(self.url,
			rg.run_change_password,
				'test_run_change_password', 
				'low', 
				['Vulnerability: Cross Site Request Forgery (CSRF) :: Damn Vulnerable Web Application'],
				[self.username, self.password, rg.get_random_string(4)])

	
	def test_run_file_inclusion(self):
		self.generic_test(self.url,
			rg.run_file_inclusion,
				'test_run_file_inclusion', 
				'low', 
				['Vulnerability: File Inclusion :: Damn Vulnerable Web Application'],
				['file1.txt'])


	def test_run_file_upload(self):
		self.generic_test(self.url, 
				rg.run_file_upload,
				'test_run_file_upload', 
				'low', 
				['Vulnerability: File Upload :: Damn Vulnerable Web Application'], [])


	def test_run_xss_s(self):
		self.generic_test(self.url,
			rg.run_xss_s,
			'test_run_xss_s',
			'low',
			['Vulnerability: Stored Cross Site Scripting (XSS)','Name: test<br />Message: This is a test comment.'],
			['test', 'test_run_xss_s'])
	

	def test_logout(self):
		token, c = rg.login(self.url, self.username, self.password)
		cookies = self.generate_cookies(token, 'low')
		rg.logout(self.url, c, cookies)
		self.assertTrue(token!='')

	def test_create_request_list(self):
		requests_list = rg.create_request_list(self.url, self.username, self.password)
		self.assertEqual(15, len(requests_list))


if __name__ == '__main__':
	unittest.main()



